/**
 * Ardity (Serial Communication for Arduino + Unity)
 * Author: Daniel Wilches <dwilches@gmail.com>
 *
 * This work is released under the Creative Commons Attributions license.
 * https://creativecommons.org/licenses/by/2.0/
 */

using UnityEngine;
using System.Collections;
using UnityEngine.UI;
using TMPro;

/**
 * Sample for reading using polling by yourself, and writing too.
 */
public class SampleUserPolling_ReadWrite : MonoBehaviour
{
    public SerialController serialController;
    int curModule = 1;
    public Module[] modules;
    Module activeModule;
    public TMP_InputField inputMessage;
    char[] delimeters = { ',' };
    public GameObject[] UIElements;

    // Initialization
    void Start()
    {
        serialController = GameObject.Find("SerialController").GetComponent<SerialController>();
        for (int i = 0; i < 3; i++)
        {
            UIElements[i].SetActive(false);
        }
    }

    // Executed each frame
    void Update()
    {
        //---------------------------------------------------------------------
        // Send data
        //---------------------------------------------------------------------


        //---------------------------------------------------------------------
        // Receive data
        //---------------------------------------------------------------------

        string message = serialController.ReadSerialMessage();

        if (message == null)
            return;

        // Check if the message is plain data or a connect/disconnect event.
        if (ReferenceEquals(message, SerialController.SERIAL_DEVICE_CONNECTED))
            Debug.Log("Connection established");
        else if (ReferenceEquals(message, SerialController.SERIAL_DEVICE_DISCONNECTED))
            Debug.Log("Connection attempt failed or disconnection detected");
        else
        {
            Debug.Log("Message arrived: " + message);
            string[] parsedMessage = message.Split(delimeters);
            int target = int.Parse(parsedMessage[0])-1;
            int request = int.Parse(parsedMessage[1]);
            int value = int.Parse(parsedMessage[2]);
            if (request == 0)
            {
                modules[target].SetPeripheral(value);
            } else if (request == 2)
            {
                modules[target].SetCapTouch(value);
            }
        }
    }

    public void SendString(string toSend)
    {
        serialController.SendSerialMessage(toSend);
        Debug.Log("Sending " + toSend);
    }

    public void SetModule(int module)
    {
        curModule = module+1;
        activeModule = modules[module];
        for (int i = 0; i < 3; i++)
        {
            if (modules[module].peripheral == (Module.Peripheral)(i + 1))
            {
                UIElements[i].SetActive(true);
            } else
            {
                UIElements[i].SetActive(false);
            }
        }
        Debug.Log("Set current module to " + curModule);
    }

    public void ToggleVibration()
    {
        bool turnOn = activeModule.ToggleVibration();
        string toSend = "{" + curModule.ToString() + ",1," + (turnOn ? "1" : "0") + "}";
        SendString(toSend);
    }

    public void SendInput()
    {
        string toSend = "{" + curModule.ToString() + ",3," + inputMessage.text + "}";
        SendString(toSend);
        inputMessage.text = "";
    }

    public void GetCap()
    {
        string toSend = "{" + curModule.ToString() + ",2}";
        SendString(toSend);
    }

    public void SetDisplay(int newDisplay)
    {
        string toSend = "{" + curModule.ToString() + ",3," + (newDisplay == 4 ? "66" : newDisplay.ToString()) + "}";
        SendString(toSend);
    }
}
