﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class Module : MonoBehaviour
{
    public SerialController serialController;
    public int id;
    public enum Peripheral
    {
        None,
        Vibration,
        Touch,
        Display
    };
    public enum DisplayModes
    {
        Set,
        On,
        Off,
        Toggle,
        Notify,
        Echo,
        Pulse,
        RingCC,
        RingCW,
        Stars,
        Clock,
    };
    public enum CapTouch
    {
        None,
        Left,
        Right,
        Both
    };
    const float pollDelay = 0.1f; // poll capacitive touch every 1/10th of a second

    public Peripheral peripheral = Peripheral.None;
    public DisplayModes displayMode = DisplayModes.Set;
    public bool vibrating = false;
    public CapTouch lastCapTouch = CapTouch.None;
    public Sprite[] images, capImages, vibeImages;
    float startTime;
    bool canRequestTouch;

    // Start is called before the first frame update
    void Start()
    {
        serialController = GameObject.Find("SerialController").GetComponent<SerialController>();

    }

    // Update is called once per frame
    void Update()
    {
        if (peripheral == Peripheral.Touch && canRequestTouch && Time.time - startTime > pollDelay)
        {
            string toSend = "{" + id.ToString() + ",2}";
            serialController.SendSerialMessage(toSend);
            startTime = Time.time;
        }
    }

    public bool ToggleVibration()
    {
        vibrating = !vibrating;
        Button button = GetComponent<Button>();
        button.GetComponent<Image>().sprite = vibeImages[vibrating ? 1 : 0];
        return vibrating;
    }

    public void SetPeripheral(int value)
    {
        canRequestTouch = true;
        startTime = Time.time;
        peripheral = (Peripheral)value;
        Button button = GetComponent<Button>();
        button.GetComponent<Image>().sprite = images[value];
    }

    public void SetCapTouch(int value)
    {
        canRequestTouch = true;
        if (value <= 3)
        {
            if (value != (int)lastCapTouch)
            {
                Button button = GetComponent<Button>();
                button.GetComponent<Image>().sprite = capImages[value];
                lastCapTouch = (CapTouch)value;
            }
        }
    }
}
